@@ -136,6 +136,11 @@ static void initialize_gui(GmpvApplication *app)
 				G_CALLBACK(shutdown_handler),
 				app );
 
+	g_settings_bind(	settings,
+				"use-skip-buttons-for-playlist",
+				controller,
+				"use-skip-buttons-for-playlist",
+				G_SETTINGS_BIND_GET );
 	g_settings_bind(	settings,
 				"always-use-floating-controls",
 				gmpv_view_get_main_window(view),
@@ -156,9 +161,9 @@ static void create_dirs()
 	gchar *scripts_dir = get_scripts_dir_path();
 	gchar *watch_dir = get_watch_dir_path();
 
-	g_mkdir_with_parents(config_dir, 0600);
-	g_mkdir_with_parents(scripts_dir, 0700);
-	g_mkdir_with_parents(watch_dir, 0600);
+	g_mkdir_with_parents(config_dir, 0755);
+	g_mkdir_with_parents(scripts_dir, 0755);
+	g_mkdir_with_parents(watch_dir, 0755);
 
 	g_free(config_dir);
 	g_free(scripts_dir);
@@ -289,18 +294,17 @@ static gint command_line_handler(	GApplication *gapp,
 				(cli, argv[i+1]);
 	}
 
-	/* If always-open-new-window is set, only activate the new-window action
-	 * if there are no files to be opened. If there are files,
-	 * open_handler() will activate the action by itself. This is necessary
-	 * because when opening files from file managers, files to be opened may
-	 * be sent in the form of DBus message, bypassing this function
-	 * entirely.
+	/* Only activate the new-window action or emit the activate signal if
+	 * there are no files to be opened. If there are files, open_handler()
+	 * will activate the action by itself. This is necessary because when
+	 * opening files from file managers, files to be opened may be sent in
+	 * the form of DBus message, bypassing this function entirely.
 	 */
 	if(app->new_window || (n_files == 0 && always_open_new_window))
 	{
 		activate_action_string(G_ACTION_MAP(gapp), "new-window");
 	}
-	else if(n_files == 0 || !app->controllers)
+	else if(n_files == 0 && !app->controllers)
 	{
 		g_application_activate(gapp);
 	}
@@ -434,7 +438,7 @@ static void gmpv_application_init(GmpvApplication *app)
 		(	G_APPLICATION(app),
 			"no-existing-session",
 			'\0',
-			G_OPTION_FLAG_NONE,
+			G_OPTION_FLAG_HIDDEN,
 			G_OPTION_ARG_NONE,
 			_("Don't connect to an already-running instance"),
 			NULL );
