@@ -32,8 +32,6 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE(GmpvApplication, gmpv_application, GMPV, APPLICATION, GtkApplication)
 
 GmpvApplication *gmpv_application_new(gchar *id, GApplicationFlags flags);
-GmpvMainWindow *gmpv_application_get_main_window(GmpvApplication *app);
-GmpvMpv *gmpv_application_get_mpv(GmpvApplication *app);
 void gmpv_application_quit(GmpvApplication *app);
 
 G_END_DECLS
