@@ -44,6 +44,8 @@ struct _GmpvPlaylistEntry
 {
 	gchar *filename;
 	gchar *title;
+	gdouble duration;
+	GPtrArray *metadata;
 };
 
 struct _GmpvMetadataEntry
@@ -73,11 +75,13 @@ void gmpv_track_free(GmpvTrack *entry);
 
 gchar *get_config_dir_path(void);
 gchar *get_scripts_dir_path(void);
+gchar *get_watch_dir_path(void);
 gchar *get_path_from_uri(const gchar *uri);
 gchar *get_name_from_path(const gchar *path);
 gboolean extension_matches(const gchar *filename, const gchar **extensions);
 void *gslist_to_array(GSList *slist);
 gchar *strnjoinv(const gchar *separator, const gchar **str_array, gsize count);
+void activate_action_string(GActionMap *map, const gchar *str);
 
 G_END_DECLS
 
