@@ -71,6 +71,8 @@ static void playlist_reordered_handler(	GmpvView *view,
 					gint src,
 					gint dst,
 					gpointer data );
+static void set_use_skip_button_for_playlist(	GmpvController *controller,
+						gboolean value);
 static void connect_signals(GmpvController *controller);
 static gboolean update_seek_bar(gpointer data);
 static gboolean is_more_than_one(	GBinding *binding,
@@ -86,6 +88,9 @@ static void playlist_handler(		GObject *object,
 static void vid_handler(		GObject *object,
 					GParamSpec *pspec,
 					gpointer data);
+static void window_scale_handler(		GObject *object,
+						GParamSpec *pspec,
+						gpointer data);
 static void model_ready_handler(	GObject *object,
 					GParamSpec *pspec,
 					gpointer data );
@@ -104,6 +109,11 @@ static void window_move_handler(	GmpvModel *model,
 static void message_handler(GmpvMpv *mpv, const gchar *message, gpointer data);
 static void error_handler(GmpvMpv *mpv, const gchar *message, gpointer data);
 static void shutdown_handler(GmpvMpv *mpv, gpointer data);
+static gboolean update_window_scale(gpointer data);
+static void video_area_resize_handler(	GmpvView *view,
+					gint width,
+					gint height,
+					gpointer data );
 static void fullscreen_handler(		GObject *object,
 					GParamSpec *pspec,
 					gpointer data );
@@ -184,6 +194,12 @@ static void set_property(	GObject *object,
 		self->idle = g_value_get_boolean(value);
 		break;
 
+		case PROP_USE_SKIP_BUTTONS_FOR_PLAYLIST:
+		self->use_skip_buttons_for_playlist = g_value_get_boolean(value);
+		set_use_skip_button_for_playlist
+			(self, self->use_skip_buttons_for_playlist);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -211,6 +227,10 @@ static void get_property(	GObject *object,
 		g_value_set_boolean(value, self->idle);
 		break;
 
+		case PROP_USE_SKIP_BUTTONS_FOR_PLAYLIST:
+		g_value_set_boolean(value, self->use_skip_buttons_for_playlist);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -370,11 +390,35 @@ static void playlist_reordered_handler(	GmpvView *view,
 	gmpv_model_move_playlist_entry(GMPV_CONTROLLER(data)->model, src, dst);
 }
 
+static void set_use_skip_button_for_playlist(	GmpvController *controller,
+						gboolean value )
+{
+	if(controller->skip_buttons_binding)
+	{
+		g_binding_unbind(controller->skip_buttons_binding);
+	}
+
+	controller->skip_buttons_binding
+		= g_object_bind_property_full
+			(	controller->model,
+				value?"playlist-count":"chapters",
+				controller->view,
+				"skip-enabled",
+				G_BINDING_DEFAULT|G_BINDING_SYNC_CREATE,
+				is_more_than_one,
+				NULL,
+				NULL,
+				NULL );
+}
+
 static void connect_signals(GmpvController *controller)
 {
 	g_object_bind_property(	controller->model, "core-idle",
 				controller, "idle",
 				G_BINDING_DEFAULT );
+	g_object_bind_property(	controller->model, "fullscreen",
+				controller->view, "fullscreen",
+				G_BINDING_BIDIRECTIONAL );
 	g_object_bind_property(	controller->model, "pause",
 				controller->view, "pause",
 				G_BINDING_DEFAULT );
@@ -393,13 +437,6 @@ static void connect_signals(GmpvController *controller)
 	g_object_bind_property(	controller->model, "track-list",
 				controller->view, "track-list",
 				G_BINDING_DEFAULT );
-	g_object_bind_property_full(	controller->model, "chapters",
-					controller->view, "chapters-enabled",
-					G_BINDING_DEFAULT,
-					is_more_than_one,
-					NULL,
-					NULL,
-					NULL );
 
 	g_signal_connect(	controller->model,
 				"notify::ready",
@@ -417,6 +454,10 @@ static void connect_signals(GmpvController *controller)
 				"notify::vid",
 				G_CALLBACK(vid_handler),
 				controller );
+	g_signal_connect(	controller->model,
+				"notify::window-scale",
+				G_CALLBACK(window_scale_handler),
+				controller );
 	g_signal_connect(	controller->model,
 				"frame-ready",
 				G_CALLBACK(frame_ready_handler),
@@ -446,6 +487,10 @@ static void connect_signals(GmpvController *controller)
 				G_CALLBACK(shutdown_handler),
 				controller );
 
+	g_signal_connect(	controller->view,
+				"video-area-resize",
+				G_CALLBACK(video_area_resize_handler),
+				controller );
 	g_signal_connect(	controller->view,
 				"notify::fullscreen",
 				G_CALLBACK(fullscreen_handler),
@@ -611,6 +656,33 @@ static void vid_handler(	GObject *object,
 	g_free(vid_str);
 }
 
+static void window_scale_handler(	GObject *object,
+					GParamSpec *pspec,
+					gpointer data )
+{
+	GmpvController *controller = data;
+	gint64 video_width = 1;
+	gint64 video_height = 1;
+	gint width = 1;
+	gint height = 1;
+	gdouble window_scale = 1.0;
+	gdouble new_window_scale = 1.0;
+
+	gmpv_model_get_video_geometry(	controller->model,
+					&video_width,
+					&video_height );
+	gmpv_view_get_video_area_geometry(controller->view, &width, &height);
+	g_object_get(object, "window-scale", &new_window_scale, NULL);
+
+	window_scale = MIN(	width/(gdouble)video_width,
+				height/(gdouble)video_height );
+
+	if(ABS(window_scale-new_window_scale) > 0.0001)
+	{
+		gmpv_controller_autofit(data, new_window_scale);
+	}
+}
+
 static void model_ready_handler(	GObject *object,
 					GParamSpec *pspec,
 					gpointer data )
@@ -722,6 +794,63 @@ static void shutdown_handler(GmpvMpv *mpv, gpointer data)
 	g_signal_emit_by_name(data, "shutdown");
 }
 
+static gboolean update_window_scale(gpointer data)
+{
+	gpointer *params = data;
+	GmpvController *controller = GMPV_CONTROLLER(params[0]);
+	gint64 video_width = 1;
+	gint64 video_height = 1;
+	gint width = 1;
+	gint height = 1;
+	gdouble window_scale = 0;
+	gdouble new_window_scale = 0;
+
+	gmpv_model_get_video_geometry(	controller->model,
+					&video_width,
+					&video_height );
+	gmpv_view_get_video_area_geometry(controller->view, &width, &height);
+
+	new_window_scale = MIN(	width/(gdouble)video_width,
+				height/(gdouble)video_height );
+	g_object_get(controller->model, "window-scale", &window_scale, NULL);
+
+	if(ABS(window_scale-new_window_scale) > 0.0001)
+	{
+		g_object_set(	controller->model,
+				"window-scale",
+				new_window_scale,
+				NULL );
+	}
+
+	// Clear event source ID for the timeout
+	*((guint *)params[1]) = 0;
+	g_free(params);
+
+	return FALSE;
+}
+
+static void video_area_resize_handler(	GmpvView *view,
+				gint width,
+				gint height,
+				gpointer data )
+{
+	static guint timeout_tag = 0;
+	gpointer *params = g_new(gpointer, 2);
+
+	if(timeout_tag > 0)
+	{
+		g_source_remove(timeout_tag);
+		timeout_tag = 0;
+	}
+
+	params[0] = data;
+	params[1] = &timeout_tag;
+
+	// Rate-limit the call to update_window_scale(), which will update the
+	// window-scale property in the model, to no more than once every 250ms.
+	timeout_tag = g_timeout_add(250, update_window_scale, params);
+}
+
 static void fullscreen_handler(		GObject *object,
 					GParamSpec *pspec,
 					gpointer data )
@@ -778,12 +907,30 @@ static void rewind_button_handler(GtkButton *button, gpointer data)
 
 static void next_button_handler(GtkButton *button, gpointer data)
 {
-	gmpv_model_next_chapter(GMPV_CONTROLLER(data)->model);
+	GmpvController *controller = data;
+
+	if(controller->use_skip_buttons_for_playlist)
+	{
+		gmpv_model_next_playlist_entry(GMPV_CONTROLLER(data)->model);
+	}
+	else
+	{
+		gmpv_model_next_chapter(GMPV_CONTROLLER(data)->model);
+	}
 }
 
 static void previous_button_handler(GtkButton *button, gpointer data)
 {
-	gmpv_model_previous_chapter(GMPV_CONTROLLER(data)->model);
+	GmpvController *controller = data;
+
+	if(controller->use_skip_buttons_for_playlist)
+	{
+		gmpv_model_previous_playlist_entry(GMPV_CONTROLLER(data)->model);
+	}
+	else
+	{
+		gmpv_model_previous_chapter(GMPV_CONTROLLER(data)->model);
+	}
 }
 
 static void fullscreen_button_handler(GtkButton *button, gpointer data)
@@ -833,6 +980,14 @@ static void gmpv_controller_class_init(GmpvControllerClass *klass)
 			G_PARAM_READWRITE );
 	g_object_class_install_property(obj_class, PROP_IDLE, pspec);
 
+	pspec = g_param_spec_boolean
+		(	"use-skip-buttons-for-playlist",
+			"Use skip buttons for playlist",
+			"Whether or not to use the skip buttons to control the playlist",
+			FALSE,
+			G_PARAM_READWRITE );
+	g_object_class_install_property(obj_class, PROP_USE_SKIP_BUTTONS_FOR_PLAYLIST, pspec);
+
 	g_signal_new(	"shutdown",
 			G_TYPE_FROM_CLASS(klass),
 			G_SIGNAL_RUN_FIRST,
@@ -853,6 +1008,7 @@ static void gmpv_controller_init(GmpvController *controller)
 	controller->idle = TRUE;
 	controller->target_playlist_pos = -1;
 	controller->update_seekbar_id = 0;
+	controller->skip_buttons_binding = NULL;
 	controller->settings = g_settings_new(CONFIG_ROOT);
 	controller->media_keys = NULL;
 	controller->mpris = NULL;
