@@ -41,6 +41,7 @@ enum
 	PROP_IDLE_ACTIVE,
 	PROP_FULLSCREEN,
 	PROP_PAUSE,
+	PROP_LOOP_FILE,
 	PROP_LOOP_PLAYLIST,
 	PROP_DURATION,
 	PROP_MEDIA_TITLE,
@@ -48,6 +49,7 @@ enum
 	PROP_PLAYLIST_POS,
 	PROP_SPEED,
 	PROP_VOLUME,
+	PROP_WINDOW_SCALE,
 	N_PROPERTIES
 };
 
@@ -69,6 +71,7 @@ struct _GmpvModel
 	gboolean idle_active;
 	gboolean fullscreen;
 	gboolean pause;
+	gchar *loop_file;
 	gchar *loop_playlist;
 	gdouble duration;
 	gchar *media_title;
@@ -76,6 +79,7 @@ struct _GmpvModel
 	gint64 playlist_pos;
 	gdouble speed;
 	gdouble volume;
+	gdouble window_scale;
 };
 
 struct _GmpvModelClass
@@ -242,6 +246,11 @@ static void set_property(	GObject *object,
 
 		case PROP_IDLE_ACTIVE:
 		self->idle_active = g_value_get_boolean(value);
+
+		if(self->idle_active)
+		{
+			g_object_notify(object, "playlist-pos");
+		}
 		break;
 
 		case PROP_FULLSCREEN:
@@ -252,7 +261,13 @@ static void set_property(	GObject *object,
 		self->pause = g_value_get_boolean(value);
 		break;
 
+		case PROP_LOOP_FILE:
+		g_free(self->loop_file);
+		self->loop_file = g_value_dup_string(value);
+		break;
+
 		case PROP_LOOP_PLAYLIST:
+		g_free(self->loop_playlist);
 		self->loop_playlist = g_value_dup_string(value);
 		break;
 
@@ -281,6 +296,10 @@ static void set_property(	GObject *object,
 		self->volume = g_value_get_double(value);
 		break;
 
+		case PROP_WINDOW_SCALE:
+		self->window_scale = g_value_get_double(value);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -354,6 +373,10 @@ static void get_property(	GObject *object,
 		g_value_set_boolean(value, self->pause);
 		break;
 
+		case PROP_LOOP_FILE:
+		g_value_set_string(value, self->loop_file);
+		break;
+
 		case PROP_LOOP_PLAYLIST:
 		g_value_set_string(value, self->loop_playlist);
 		break;
@@ -382,6 +405,10 @@ static void get_property(	GObject *object,
 		g_value_set_double(value, self->volume);
 		break;
 
+		case PROP_WINDOW_SCALE:
+		g_value_set_double(value, self->window_scale);
+		break;
+
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
 		break;
@@ -410,6 +437,7 @@ static void finalize(GObject *object)
 	g_free(model->aid);
 	g_free(model->vid);
 	g_free(model->sid);
+	g_free(model->loop_file);
 	g_free(model->loop_playlist);
 	g_free(model->media_title);
 
@@ -461,6 +489,13 @@ static void set_mpv_property(	GObject *object,
 					&self->pause );
 		break;
 
+		case PROP_LOOP_FILE:
+		gmpv_mpv_set_property(	mpv,
+					"loop-file",
+					MPV_FORMAT_STRING,
+					&self->loop_file );
+		break;
+
 		case PROP_LOOP_PLAYLIST:
 		gmpv_mpv_set_property(	mpv,
 					"loop-playlist",
@@ -495,6 +530,13 @@ static void set_mpv_property(	GObject *object,
 					MPV_FORMAT_DOUBLE,
 					&self->volume );
 		break;
+
+		case PROP_WINDOW_SCALE:
+		gmpv_mpv_set_property(	mpv,
+					"window-scale",
+					MPV_FORMAT_DOUBLE,
+					&self->window_scale );
+		break;
 	}
 }
 
@@ -685,6 +727,7 @@ static void gmpv_model_class_init(GmpvModelClass *klass)
 			{"idle-active", PROP_IDLE_ACTIVE, G_TYPE_BOOLEAN},
 			{"fullscreen", PROP_FULLSCREEN, G_TYPE_BOOLEAN},
 			{"pause", PROP_PAUSE, G_TYPE_BOOLEAN},
+			{"loop-file", PROP_LOOP_FILE, G_TYPE_STRING},
 			{"loop-playlist", PROP_LOOP_PLAYLIST, G_TYPE_STRING},
 			{"duration", PROP_DURATION, G_TYPE_DOUBLE},
 			{"media-title", PROP_MEDIA_TITLE, G_TYPE_STRING},
@@ -692,6 +735,7 @@ static void gmpv_model_class_init(GmpvModelClass *klass)
 			{"playlist-pos", PROP_PLAYLIST_POS, G_TYPE_INT64},
 			{"speed", PROP_SPEED, G_TYPE_DOUBLE},
 			{"volume", PROP_VOLUME, G_TYPE_DOUBLE},
+			{"window-scale", PROP_WINDOW_SCALE, G_TYPE_DOUBLE},
 			{NULL, PROP_INVALID, 0} };
 
 	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
@@ -850,6 +894,7 @@ static void gmpv_model_init(GmpvModel *model)
 	model->idle_active = FALSE;
 	model->fullscreen = FALSE;
 	model->pause = TRUE;
+	model->loop_file = NULL;
 	model->loop_playlist = NULL;
 	model->duration = 0.0;
 	model->media_title = NULL;
@@ -857,6 +902,7 @@ static void gmpv_model_init(GmpvModel *model)
 	model->playlist_pos = 0;
 	model->speed = 1.0;
 	model->volume = 1.0;
+	model->window_scale = 1.0;
 }
 
 GmpvModel *gmpv_model_new(gint64 wid)
@@ -1048,42 +1094,17 @@ gdouble gmpv_model_get_time_position(GmpvModel *model)
 
 void gmpv_model_set_playlist_position(GmpvModel *model, gint64 position)
 {
-	if(position != model->playlist_pos)
-	{
-		gmpv_mpv_set_property(	GMPV_MPV(model->player),
-					"playlist-pos",
-					MPV_FORMAT_INT64,
-					&position );
-	}
+	gmpv_player_set_playlist_position(model->player, position);
 }
 
 void gmpv_model_remove_playlist_entry(GmpvModel *model, gint64 position)
 {
-	const gchar *cmd[] = {"playlist_remove", NULL, NULL};
-	gchar *index_str = g_strdup_printf("%" G_GINT64_FORMAT, position);
-
-	cmd[1] = index_str;
-
-	gmpv_mpv_command(GMPV_MPV(model->player), cmd);
-
-	g_free(index_str);
+	gmpv_player_remove_playlist_entry(model->player, position);
 }
 
 void gmpv_model_move_playlist_entry(GmpvModel *model, gint64 src, gint64 dst)
 {
-	const gchar *cmd[] =	{"playlist_move", NULL, NULL, NULL};
-	gchar *src_str =	g_strdup_printf
-				("%" G_GINT64_FORMAT, (src > dst)?--src:src);
-	gchar *dst_str =	g_strdup_printf
-				("%" G_GINT64_FORMAT, dst);
-
-	cmd[1] = src_str;
-	cmd[2] = dst_str;
-
-	gmpv_mpv_command(GMPV_MPV(model->player), cmd);
-
-	g_free(src_str);
-	g_free(dst_str);
+	gmpv_player_move_playlist_entry(model->player, src, dst);
 }
 
 void gmpv_model_load_file(GmpvModel *model, const gchar *uri, gboolean append)
@@ -1144,3 +1165,4 @@ gchar *gmpv_model_get_current_path(GmpvModel *model)
 
 	return buf;
 }
+
