@@ -350,8 +350,10 @@ static void drag_data_received_handler(	GtkWidget *widget,
 					gpointer data)
 {
 	GmpvPlaylistWidget *wgt = data;
-	gchar *type = gdk_atom_name(gtk_selection_data_get_target(sel_data));
 	gboolean reorder = (widget == gtk_drag_get_source_widget(context));
+#ifndef G_DISABLE_ASSERT /* Only used in an assertion below */
+	gchar *type = gdk_atom_name(gtk_selection_data_get_target(sel_data));
+#endif
 
 	if(reorder)
 	{
@@ -524,7 +526,8 @@ static gboolean mouse_press_handler(	GtkWidget *widget,
 		GMenuItem *add_menu_item;
 		GMenuItem *add_loc_menu_item;
 		GMenuItem *shuffle_menu_item;
-		GMenuItem *loop_menu_item;
+		GMenuItem *loop_file_menu_item;
+		GMenuItem *loop_playlist_menu_item;
 		GtkWidget *ctx_menu;
 
 		menu = g_menu_new();
@@ -536,13 +539,24 @@ static gboolean mouse_press_handler(	GtkWidget *widget,
 			=	g_menu_item_new
 				(	_("Add _Location…"),
 					"win.show-open-location-dialog(true)" );
-		shuffle_menu_item = g_menu_item_new(_("_Shuffle"), "win.shuffle-playlist");
-		loop_menu_item = g_menu_item_new(_("L_oop"), "win.toggle-loop");
+		shuffle_menu_item
+			=	g_menu_item_new
+				(	_("_Shuffle"),
+					"win.shuffle-playlist" );
+		loop_file_menu_item
+			=	g_menu_item_new
+				(	_("Loop _File"),
+					"win.toggle-loop-file" );
+		loop_playlist_menu_item
+			=	g_menu_item_new
+				(	_("Loop _Playlist"),
+					"win.toggle-loop-playlist" );
 
 		g_menu_append_item(menu, add_menu_item);
 		g_menu_append_item(menu, add_loc_menu_item);
 		g_menu_append_item(menu, shuffle_menu_item);
-		g_menu_append_item(menu, loop_menu_item);
+		g_menu_append_item(menu, loop_file_menu_item);
+		g_menu_append_item(menu, loop_playlist_menu_item);
 		g_menu_freeze(menu);
 
 		ctx_menu = gtk_menu_new_from_model(G_MENU_MODEL(menu));
